@@ -107,11 +107,10 @@ KOAgendaView::KOAgendaView(QWidget *parent, bool isSideBySide)
 
 KOAgendaView::~KOAgendaView() = default;
 
-void KOAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &cal)
+void KOAgendaView::setModel(QAbstractItemModel *model)
 {
-    KOEventView::setCalendar(cal);
-    d->mPopup->setCalendar(cal);
-    d->mAgendaView->setCalendar(cal);
+    KOEventView::setModel(model);
+    d->mAgendaView->setModel(model);
 }
 
 void KOAgendaView::zoomInVertically()
@@ -290,3 +289,15 @@ void KOAgendaView::setDateRange(const QDateTime &start, const QDateTime &end, co
 {
     d->mAgendaView->setDateRange(start, end);
 }
+
+void KOAgendaView::calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    d->mAgendaView->addCalendar(calendar);
+}
+
+void KOAgendaView::calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar)
+{
+    d->mAgendaView->removeCalendar(calendar);
+}
+
+#include "moc_koagendaview.cpp"
